==> aws-java-sdk-sqs-1.9.32-sources.jar: com/amazonaws/services/sqs/model/transform/DeleteMessageBatchResultEntryStaxUnmarshaller.java <==
/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.sqs.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import javax.xml.stream.events.XMLEvent;

import com.amazonaws.services.sqs.model.*;
import com.amazonaws.transform.Unmarshaller;
import com.amazonaws.transform.MapEntry;
import com.amazonaws.transform.StaxUnmarshallerContext;
import com.amazonaws.transform.SimpleTypeStaxUnmarshallers.*;

/**
 * Delete Message Batch Result Entry StAX Unmarshaller
 */
public class DeleteMessageBatchResultEntryStaxUnmarshaller implements Unmarshaller<DeleteMessageBatchResultEntry, StaxUnmarshallerContext> {

    public DeleteMessageBatchResultEntry unmarshall(StaxUnmarshallerContext context) throws Exception {
        DeleteMessageBatchResultEntry deleteMessageBatchResultEntry = new DeleteMessageBatchResultEntry();
        int originalDepth = context.getCurrentDepth();
        int targetDepth = originalDepth + 1;

        if (context.isStartOfDocument()) targetDepth += 2;

        while (true) {
            XMLEvent xmlEvent = context.nextEvent();
            if (xmlEvent.isEndDocument()) return deleteMessageBatchResultEntry;

            if (xmlEvent.isAttribute() || xmlEvent.isStartElement()) {
                if (context.testExpression("Id", targetDepth)) {
                    deleteMessageBatchResultEntry.setId(StringStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
            } else if (xmlEvent.isEndElement()) {
                if (context.getCurrentDepth() < originalDepth) {
                    return deleteMessageBatchResultEntry;
                }
            }
        }
    }

    private static DeleteMessageBatchResultEntryStaxUnmarshaller instance;
    public static DeleteMessageBatchResultEntryStaxUnmarshaller getInstance() {
        if (instance == null) instance = new DeleteMessageBatchResultEntryStaxUnmarshaller();
        return instance;
    }
}

==> aws-java-sdk-sqs-1.10.44-sources.jar: com/amazonaws/services/sqs/model/transform/DeleteMessageBatchResultEntryStaxUnmarshaller.java <==
/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.sqs.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import javax.xml.stream.events.XMLEvent;

import com.amazonaws.services.sqs.model.*;
import com.amazonaws.transform.Unmarshaller;
import com.amazonaws.transform.MapEntry;
import com.amazonaws.transform.StaxUnmarshallerContext;
import com.amazonaws.transform.SimpleTypeStaxUnmarshallers.*;

/**
 * DeleteMessageBatchResultEntry StAX Unmarshaller
 */
public class DeleteMessageBatchResultEntryStaxUnmarshaller implements
        Unmarshaller<DeleteMessageBatchResultEntry, StaxUnmarshallerContext> {

    public DeleteMessageBatchResultEntry unmarshall(
            StaxUnmarshallerContext context) throws Exception {
        DeleteMessageBatchResultEntry deleteMessageBatchResultEntry = new DeleteMessageBatchResultEntry();
        int originalDepth = context.getCurrentDepth();
        int targetDepth = originalDepth + 1;

        if (context.isStartOfDocument())
            targetDepth += 1;

        while (true) {
            XMLEvent xmlEvent = context.nextEvent();
            if (xmlEvent.isEndDocument())
                return deleteMessageBatchResultEntry;

            if (xmlEvent.isAttribute() || xmlEvent.isStartElement()) {

                if (context.testExpression("Id", targetDepth)) {
                    deleteMessageBatchResultEntry.setId(StringStaxUnmarshaller
                            .getInstance().unmarshall(context));
                    continue;
                }
            } else if (xmlEvent.isEndElement()) {
                if (context.getCurrentDepth() < originalDepth) {
                    return deleteMessageBatchResultEntry;
                }
            }
        }
    }

    private static DeleteMessageBatchResultEntryStaxUnmarshaller instance;

    public static DeleteMessageBatchResultEntryStaxUnmarshaller getInstance() {
        if (instance == null)
            instance = new DeleteMessageBatchResultEntryStaxUnmarshaller();
        return instance;
    }
}
